@@ -1,5 +1,7 @@
+from __future__ import annotations
+
 from pathlib import Path
-from typing import Any, Dict, List, Optional, Set
+from typing import Any, Dict, List, Optional, Set, Union,TYPE_CHECKING
 from pyvisflow.core.components.containers import BoxContainer, Component
 from pyvisflow.core.components import DataTable, EChart
 from pyvisflow.core.dataManager import DataFrameManager
@@ -13,6 +15,10 @@ from pyvisflow.utils.data_gen import get_project_root, json_dumps_fn
 from pyvisflow.utils.helper import flatten
 import pandas as pd
 import re
+from pyvisflow.core.components.file import FileData
+if TYPE_CHECKING:
+    from pyvisflow.core.reactive import Reactive
+    
 
 __scripts_mapping__ = {'plotly': 'plotly-2.9.0.min.js'}
 __re_app_div__ = re.compile(r'<div\sid="app"></div>')
@@ -21,14 +27,18 @@ __re_app_div__ = re.compile(r'<div\sid="app"></div>')
 class App(BoxContainer):
     def __init__(self) -> None:
         super().__init__()
-        self.structures: List[Structure] = []
+        self.structures: List[Reactive] = []
         self.df_manager = DataFrameManager()
         self._scripts: Set[str] = set()
         self.fns = Fns(self)
 
-        def on_before_data_fn(data: pd.DataFrame):
+        def on_before_data_fn(data: Union[pd.DataFrame,FileData]):
             if isinstance(data, pd.DataFrame):
-                return self.df_manager.mark_data(data)
+                return self.df_manager.mark_dataframe(data)
+
+            if isinstance(data,FileData):
+                self.structures.append(data)
+                return self.df_manager.mark_fileData(data)
 
             return data
 
