@@ -12,13 +12,16 @@ from pyvisflow.core.components.inputNumber import InputNumber
 from pyvisflow.core.components.plotly import Plotly
 from pyvisflow.core.components.select import Select
 from pyvisflow.core.components.text import Text
+from pyvisflow.core.components.file import File
+
 from pyvisflow.core.layout import MarkdownLayout
-from pyvisflow.core.props import BoolTypePropInfo, NamePropInfo
+from pyvisflow.core.props import BoolTypePropInfo
 
 from pyvisflow.models.TComponent import TComponentType
 
 if TYPE_CHECKING:
     from pyvisflow.core.props import TypePropInfo
+    from pyvisflow.core.components.file import FileData
 
 
 class Container(Component):
@@ -43,6 +46,12 @@ class BoxContainer(Container):
     def __default_on_before_add_child_fn(cp: Component):
         pass
 
+    def file(self):
+        cp = File()
+        self._on_before_add_child_fn(cp)
+        self.add_child(cp)
+        return cp
+
     def box(self, ):
         cp = BoxContainer()
         cp._on_before_data_fn = self._on_before_data_fn
@@ -75,7 +84,7 @@ class BoxContainer(Container):
         self.add_child(cp)
         return cp
 
-    def dataTable(self, dataframe: pd.DataFrame, page_size=5):
+    def dataTable(self, dataframe: Union[pd.DataFrame,FileData], page_size=5):
         cp = DataTable(self._on_before_data_fn(dataframe))
         cp.page_size = page_size
         self._on_before_add_child_fn(cp)
