@@ -5,6 +5,7 @@ from pyvisflow.models.TWatchInfo import TWatchInfo
 from .TComponent import TComponent
 from .TStaticData import TStaticData
 
+from pyvisflow.utils.data_gen import json_dumps_fn
 
 class TReactData(BaseModel):
     id: str
@@ -16,3 +17,8 @@ class TConfig(BaseModel):
     cps: List[TComponent]
     reactDatas: Optional[List[TReactData]] = []
     watchInfo: TWatchInfo
+
+
+    class Config:
+        json_dumps = json_dumps_fn
+
