@@ -1,6 +1,8 @@
+from datetime import datetime
 from pathlib import Path
 from json import JSONEncoder, dumps
 from functools import partial
+import numpy as np
 import pandas as pd
 
 _global_id = 0
@@ -20,12 +22,20 @@ def get_project_root():
 
 
 def _nan2None(obj):
+
+
+
     if isinstance(obj, dict):
         return {k: _nan2None(v) for k, v in obj.items()}
     elif isinstance(obj, list):
         return [_nan2None(v) for v in obj]
     elif isinstance(obj, float) and pd.isna(obj):
         return None
+    elif isinstance(obj,np.ndarray):
+        return obj.tolist()
+    elif isinstance(obj,datetime):
+        return str(obj)
+
     return obj
 
 
